==> VVAS-DataCenter-core-6.0.0-sources.jar: com/viontech/keliu/model/Feature.java <==
package com.viontech.keliu.model;

import com.viontech.keliu.model.FaceKey;
import com.viontech.keliu.model.ROI;

import java.util.List;

public class Feature {
	private String filename;//照片名称
	private String type;//特征类型：人脸 face / 人体 body
	private List<Data> datas;//特征数据
	private List<ROI> face_roi;//人脸roi 仅type为face时存在
	private List<ROI> body_roi;//有效身体roi 仅type为body时存在
	private Float face_score;//得分 仅type为face时存在
	private Integer face_type;//人脸类型 仅type为face时存在
	private List<FaceKey> key_point;//关键点 仅type为face时存在

	public String getFilename() {
		return filename;
	}

	public void setFilename(String filename) {
		this.filename = filename;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public List<Data> getDatas() {
		return datas;
	}

	public void setDatas(List<Data> datas) {
		this.datas = datas;
	}

	public List<ROI> getFace_roi() {
		return face_roi;
	}

	public void setFace_roi(List<ROI> face_roi) {
		this.face_roi = face_roi;
	}

	public List<ROI> getBody_roi() {
		return body_roi;
	}

	public void setBody_roi(List<ROI> body_roi) {
		this.body_roi = body_roi;
	}

	public Float getFace_score() {
		return face_score;
	}

	public void setFace_score(Float face_score) {
		this.face_score = face_score;
	}

	public Integer getFace_type() {
		return face_type;
	}

	public void setFace_type(int face_type) {
		this.face_type = face_type;
	}

	public List<FaceKey> getKey_point() {
		return key_point;
	}

	public void setKey_point(List<FaceKey> key_point) {
		this.key_point = key_point;
	}
}

==> VVAS-DataCenter-core-6.1.4-sources.jar: com/viontech/keliu/model/Feature.java <==
package com.viontech.keliu.model;

import java.io.Serializable;
import java.util.List;

public class Feature implements Serializable {
	private String filename;//照片名称
	private String type;//特征类型：人脸 face / 人体 body
	private List<Data> datas;//特征数据
	private List<ROI> face_roi;//人脸roi 仅type为face时存在
	private List<ROI> body_roi;//有效身体roi 仅type为body时存在
	private Float face_score;//得分 仅type为face时存在
	private Integer face_type;//人脸类型 仅type为face时存在
	private List<FaceKey> key_point;//关键点 仅type为face时存在

	public String getFilename() {
		return filename;
	}

	public void setFilename(String filename) {
		this.filename = filename;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public List<Data> getDatas() {
		return datas;
	}

	public void setDatas(List<Data> datas) {
		this.datas = datas;
	}

	public List<ROI> getFace_roi() {
		return face_roi;
	}

	public void setFace_roi(List<ROI> face_roi) {
		this.face_roi = face_roi;
	}

	public List<ROI> getBody_roi() {
		return body_roi;
	}

	public void setBody_roi(List<ROI> body_roi) {
		this.body_roi = body_roi;
	}

	public Float getFace_score() {
		return face_score;
	}

	public void setFace_score(Float face_score) {
		this.face_score = face_score;
	}

	public Integer getFace_type() {
		return face_type;
	}

	public void setFace_type(int face_type) {
		this.face_type = face_type;
	}

	public List<FaceKey> getKey_point() {
		return key_point;
	}

	public void setKey_point(List<FaceKey> key_point) {
		this.key_point = key_point;
	}
}
